@@ -14,6 +14,7 @@ import sympy as sp
 from ampform.dynamics import (
     BlattWeisskopfSquared,
     _analytic_continuation,
+    _phase_space_factor_hat,
     breakup_momentum_squared,
     coupled_width,
     phase_space_factor,
@@ -21,6 +22,7 @@ from ampform.dynamics import (
     relativistic_breit_wigner,
     relativistic_breit_wigner_with_ff,
 )
+from ampform.dynamics.math import ComplexSqrt
 
 
 def update_docstring(
@@ -55,6 +57,18 @@ def render_breakup_momentum() -> None:
     )
 
 
+def render_complex_sqrt() -> None:
+    x = sp.Symbol("x", real=True)
+    complex_sqrt = ComplexSqrt(x)
+    update_docstring(
+        ComplexSqrt,
+        fR"""
+    .. math:: {sp.latex(complex_sqrt)} = {sp.latex(complex_sqrt.evaluate())}
+        :label: ComplexSqrt
+    """,
+    )
+
+
 def render_coupled_width() -> None:
     L = sp.Symbol("L", integer=True)
     s, m0, w0, m_a, m_b, d = sp.symbols("s m0 Gamma0 m_a m_b d")
@@ -114,16 +128,26 @@ def render_phase_space_factor() -> None:
 
 
 def render_phase_space_factor_ac() -> None:
-    s, m_a, m_b, rho = sp.symbols(R"s, m_a, m_b, \hat{\rho}")
-    rho_analytic = _analytic_continuation(rho, s, s_threshold=(m_a + m_b) ** 2)
+    s, m_a, m_b, rho_hat_symbol, q_squared_symbol = sp.symbols(
+        R"s, m_a, m_b, \hat{\rho}, q^{2}(s)"
+    )
+    rho_analytic = _analytic_continuation(
+        rho_hat_symbol, s, s_threshold=(m_a + m_b) ** 2
+    )
+    q_squared = breakup_momentum_squared(s, m_a, m_b)
+    rho_hat = _phase_space_factor_hat(s, m_a, m_b)
+    rho_hat_subs = rho_hat.subs(4 * q_squared, 4 * q_squared_symbol)
     update_docstring(
         phase_space_factor_ac,
         fR"""
     .. math:: {sp.latex(rho_analytic)}
         :label: phase_space_factor_ac
 
-    with :math:`\hat{{\rho}}` the `phase_space_factor` defined by
-    :eq:`phase_space_factor`.
+    with :math:`\hat{{\rho}}` a slightly adapted :func:`phase_space_factor`
+    that takes the absolute value of :func:`.breakup_momentum_squared`:
+
+    .. math:: {sp.latex(rho_hat_subs)}
+        :label: rho_hat
     """,
     )
 
