@@ -16,6 +16,7 @@ from .decorator import (
     implement_doit_method,
     verify_signature,
 )
+from .math import ComplexSqrt
 
 try:
     from typing import Protocol
@@ -33,7 +34,7 @@ class BlattWeisskopfSquared(UnevaluatedExpression):
         z: Argument of the Blatt-Weisskopf function :math:`B_L^2(z)`. A usual
             choice is :math:`z = (d q)^2` with :math:`d` the impact parameter
             and :math:`q` the breakup-momentum (see
-            `breakup_momentum_squared`).
+            :func:`breakup_momentum_squared`).
 
     Note that equal powers of :math:`z` appear in the nominator and the
     denominator, while some sources have nominator :math:`1`, instead of
@@ -175,7 +176,7 @@ def relativistic_breit_wigner(
 
 
 class PhaseSpaceFactor(Protocol):
-    """Protocol that is used by `.coupled_width`.
+    """Protocol that is used by :func:`.coupled_width`.
 
     Use this `~typing.Protocol` when defining other implementations of a phase
     space factor. Compare for instance :func:`.phase_space_factor` and
@@ -192,22 +193,21 @@ class PhaseSpaceFactor(Protocol):
 def phase_space_factor(
     s: sp.Symbol, m_a: sp.Symbol, m_b: sp.Symbol
 ) -> sp.Expr:
-    """Standard phase-space factor, using `breakup_momentum_squared`.
+    """Standard phase-space factor, using :func:`breakup_momentum_squared`.
 
-    See :pdg-review:`2020; Resonances; p.4`, Equation (49.8).
-
-    .. warning:: This function uses a
-        {func}`~sympy.functions.elementary.miscellaneous.sqrt`. In order to
-        enable analytic continuation, input data needs to be complex valued.
+    See :pdg-review:`2020; Resonances; p.4`, Equation (49.8), with a slight
+    adaptation: instead of a normal square root, this phase space factor make
+    use of :eq:`ComplexSqrt` (`.ComplexSqrt`).
     """
     q_squared = breakup_momentum_squared(s, m_a, m_b)
-    return sp.sqrt(q_squared) / (8 * sp.pi * sp.sqrt(s))
+    denominator = _phase_space_factor_denominator(s)
+    return ComplexSqrt(q_squared) / denominator
 
 
 def phase_space_factor_ac(
     s: sp.Symbol, m_a: sp.Symbol, m_b: sp.Symbol
 ) -> sp.Expr:
-    """Analytic continuation for the `phase_space_factor`.
+    """Analytic continuation for the :func:`phase_space_factor`.
 
     See :pdg-review:`2014; Resonances; p.8` and
     :doc:`/usage/dynamics/analytic-continuation`.
@@ -215,10 +215,22 @@ def phase_space_factor_ac(
     **Warning**: The PDG specifically derives this formula for a two-body decay
     *with equal masses*.
     """
-    q_squared = breakup_momentum_squared(s, m_a, m_b)
-    rho = sp.sqrt(sp.Abs(q_squared)) / (8 * sp.pi * sp.sqrt(s))
+    rho_hat = _phase_space_factor_hat(s, m_a, m_b)
     s_threshold = (m_a + m_b) ** 2
-    return _analytic_continuation(rho, s, s_threshold)
+    return _analytic_continuation(rho_hat, s, s_threshold)
+
+
+def _phase_space_factor_hat(
+    s: sp.Symbol, m_a: sp.Symbol, m_b: sp.Symbol
+) -> sp.Expr:
+    """Phase space factor used in the analytic continuation."""
+    q_squared = breakup_momentum_squared(s, m_a, m_b)
+    denominator = _phase_space_factor_denominator(s)
+    return sp.sqrt(sp.Abs(q_squared)) / denominator
+
+
+def _phase_space_factor_denominator(s: sp.Symbol) -> sp.Expr:
+    return 8 * sp.pi * sp.sqrt(s)
 
 
 def _analytic_continuation(
@@ -292,14 +304,21 @@ def relativistic_breit_wigner_with_ff(  # pylint: disable=too-many-arguments
 ) -> sp.Expr:
     """Relativistic Breit-Wigner with `.BlattWeisskopfSquared` factor.
 
+    Note that this lineshape is set to zero for :math:`s < (m_a + m_b)^2` as a
+    continuation of the `.BlattWeisskopfSquared` damping factor behavior at
+    :math:`s = (m_a + m_b)^2`.
+
     See :ref:`usage/dynamics/lineshapes:_With_ form factor` and
     :pdg-review:`2020; Resonances; p.6`.
     """
     q_squared = breakup_momentum_squared(s, m_a, m_b)
-    form_factor = sp.sqrt(
-        BlattWeisskopfSquared(
-            angular_momentum, z=q_squared * meson_radius ** 2
-        )
+    ff_squared = BlattWeisskopfSquared(
+        angular_momentum, z=q_squared * meson_radius ** 2
+    )
+    s_threshold = (m_a + m_b) ** 2
+    form_factor = sp.Piecewise(
+        (0, sp.And(s < s_threshold, sp.Ne(angular_momentum, 0))),
+        (sp.sqrt(ff_squared), True),
     )
     mass_dependent_width = coupled_width(
         s, mass0, gamma0, m_a, m_b, angular_momentum, meson_radius, phsp_factor
