@@ -3,7 +3,7 @@
 import logging
 import operator
 from functools import reduce
-from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
+from typing import Any, Dict, Iterable, List, Optional, Tuple, Type, Union
 
 import attr
 import sympy as sp
@@ -228,18 +228,19 @@ class _HelicityAmplitudeNameGenerator:
             nodelist = frozenset({node_id})
         else:
             nodelist = graph.topology.nodes
+        names: List[str] = []
         for node in nodelist:
             (in_hel_info, out_hel_info) = self._retrieve_helicity_info(
                 graph, node
             )
 
-            name += (
+            name = (
                 _generate_particles_string(in_hel_info)
                 + R" \to "
                 + _generate_particles_string(out_hel_info)
-                + ";"
             )
-        return name[:-1]
+            names.append(name)
+        return "; ".join(names)
 
     @staticmethod
     def _retrieve_helicity_info(
@@ -270,13 +271,13 @@ class _HelicityAmplitudeNameGenerator:
         self, graph: StateTransitionGraph[ParticleWithSpin]
     ) -> str:
         """Generate unique suffix for a sequential amplitude graph."""
-        output_suffix = ""
+        coefficient_names: List[str] = []
         for node_id in graph.topology.nodes:
             suffix = self.generate_amplitude_coefficient_name(graph, node_id)
             if suffix in self.parity_partner_coefficient_mapping:
                 suffix = self.parity_partner_coefficient_mapping[suffix]
-            output_suffix += suffix + ";"
-        return output_suffix[:-1]
+            coefficient_names.append(suffix)
+        return "; ".join(coefficient_names)
 
 
 class _CanonicalAmplitudeNameGenerator(_HelicityAmplitudeNameGenerator):
@@ -285,20 +286,20 @@ class _CanonicalAmplitudeNameGenerator(_HelicityAmplitudeNameGenerator):
         graph: StateTransitionGraph[ParticleWithSpin],
         node_id: Optional[int] = None,
     ) -> str:
-        name = ""
         if isinstance(node_id, int):
             node_ids = frozenset({node_id})
         else:
             node_ids = graph.topology.nodes
+        names: List[str] = []
         for node in node_ids:
             helicity_name = super().generate_unique_amplitude_name(graph, node)
-            name += (
+            name = (
                 helicity_name[:-1]
                 + self._generate_clebsch_gordan_string(graph, node)
                 + helicity_name[-1]
-                + ";"
             )
-        return name
+            names.append(name)
+        return "; ".join(names)
 
     @staticmethod
     def _generate_clebsch_gordan_string(
@@ -703,7 +704,7 @@ class CanonicalAmplitudeBuilder(HelicityAmplitudeBuilder):
             daughter_spins[0].projection - daughter_spins[1].projection
         )
 
-        cg_ls = _ClebschGordanLatexFix(
+        cg_ls = CG(
             j1=sp.nsimplify(ang_mom.magnitude),
             m1=sp.nsimplify(ang_mom.projection),
             j2=sp.nsimplify(spin.magnitude),
@@ -711,7 +712,7 @@ class CanonicalAmplitudeBuilder(HelicityAmplitudeBuilder):
             j3=sp.nsimplify(parent_spin.magnitude),
             m3=sp.nsimplify(decay_particle_lambda),
         )
-        cg_ss = _ClebschGordanLatexFix(
+        cg_ss = CG(
             j1=sp.nsimplify(daughter_spins[0].magnitude),
             m1=sp.nsimplify(daughter_spins[0].projection),
             j2=sp.nsimplify(daughter_spins[1].magnitude),
@@ -723,10 +724,13 @@ class CanonicalAmplitudeBuilder(HelicityAmplitudeBuilder):
 
 
 # https://github.com/sympy/sympy/issues/21001
-class _ClebschGordanLatexFix(CG):
-    def _latex(self, printer: LatexPrinter, *args: Any) -> str:
-        j3, m3, j1, m1, j2, m2 = map(  # pylint: disable=invalid-name
-            printer._print,  # pylint: disable=protected-access
-            (self.j3, self.m3, self.j1, self.m1, self.j2, self.m2),
-        )
-        return f"{{C^{j3,m3}_{j1, m1, j2, m2}}}"
+# pylint: disable=protected-access, unused-argument
+def _latex_fix(self: Type[CG], printer: LatexPrinter, *args: Any) -> str:
+    j3, m3, j1, m1, j2, m2 = map(
+        printer._print,
+        (self.j3, self.m3, self.j1, self.m1, self.j2, self.m2),
+    )
+    return f"{{C^{{{j3},{m3}}}_{{{j1},{m1},{j2},{m2}}}}}"
+
+
+CG._latex = _latex_fix
