@@ -1,8 +1,11 @@
+# pylint: disable=no-self-use
+import numpy as np
 import pytest
 import qrules as q
 import sympy as sp
 from sympy import preorder_traversal
 
+from ampform.dynamics import ComplexSqrt
 from ampform.helicity import HelicityModel
 
 
@@ -77,12 +80,14 @@ def test_generate(
     expression = sp.piecewise_fold(expression)
     assert isinstance(expression, sp.Add)
     a1, a2 = tuple(map(str, expression.args))
+    a1 = a1.replace("ComplexSqrt", "sqrt")
+    a2 = a2.replace("ComplexSqrt", "sqrt")
     if formalism == "canonical":
-        assert a1 == "0.08/(-m**2 - 0.06*I*sqrt(m**2 - 0.07)/Abs(m) + 0.98)"
-        assert a2 == "0.23/(-m**2 - 0.17*I*sqrt(m**2 - 0.07)/Abs(m) + 2.27)"
+        assert a1 == "0.08/(-m**2 + 0.98 - 0.12*I*sqrt(m**2/4 - 0.02)/Abs(m))"
+        assert a2 == "0.23/(-m**2 + 2.27 - 0.34*I*sqrt(m**2/4 - 0.02)/Abs(m))"
     elif formalism == "helicity":
-        assert a1 == "0.17/(-m**2 - 0.17*I*sqrt(m**2 - 0.07)/Abs(m) + 2.27)"
-        assert a2 == "0.06/(-m**2 - 0.06*I*sqrt(m**2 - 0.07)/Abs(m) + 0.98)"
+        assert a1 == "0.17/(-m**2 + 2.27 - 0.34*I*sqrt(m**2/4 - 0.02)/Abs(m))"
+        assert a2 == "0.06/(-m**2 + 0.98 - 0.12*I*sqrt(m**2/4 - 0.02)/Abs(m))"
     else:
         raise NotImplementedError
 
@@ -96,3 +101,43 @@ def round_nested(expression: sp.Expr, n_decimals: int) -> sp.Expr:
         if isinstance(node, sp.Pow) and node.args[1] == 1 / 2:
             expression = expression.subs(node, round(node.n(), n_decimals))
     return expression
+
+
+class TestComplexSqrt:
+    @pytest.mark.parametrize("real", [False, True])
+    def test_evaluate(self, real: bool):
+        x = sp.Symbol("x", real=real)
+        expr = ComplexSqrt(x).evaluate()
+        if real:
+            assert expr == sp.Piecewise(
+                (sp.I * sp.sqrt(-x), x < 0),
+                (sp.sqrt(x), True),
+            )
+        else:
+            assert expr == sp.sqrt(x)
+
+    def test_latex(self):
+        x = sp.Symbol("x")
+        expr = ComplexSqrt(x)
+        assert sp.latex(expr) == R"\sqrt[\mathrm{c}]{x}"
+
+    @pytest.mark.parametrize("real", [False, True])
+    @pytest.mark.parametrize("backend", ["math", "numpy"])
+    def test_lambdify(self, backend: str, real: bool):
+        x = sp.Symbol("x", real=real)
+        expression = ComplexSqrt(x)
+        lambdified = sp.lambdify(x, expression, backend)
+        assert lambdified(np.array(-1)) == 1j
+
+    @pytest.mark.parametrize(
+        ("input_value", "expected"),
+        [
+            (sp.Symbol("x", real=True), "ComplexSqrt(x)"),
+            (sp.Symbol("x"), "ComplexSqrt(x)"),
+            (+4, "2"),
+            (-4, "2*I"),
+        ],
+    )
+    def test_new(self, input_value, expected: str):
+        expr = ComplexSqrt(input_value)
+        assert str(expr) == expected
